
# Type: category type


A primitive type in which the value denotes a class within the biolink model. The value must be a URI or a CURIE. In a Neo4j representation, the value should be the CURIE for the biolink class, for example biolink:Gene. For an RDF representation, the value should be a URI such as https://w3id.org/biolink/vocab/Gene

URI: [biolink:CategoryType](https://w3id.org/biolink/vocab/CategoryType)

|  |  |  |
| --- | --- | --- |
| Parent type | | [Uriorcurie](types/Uriorcurie.md) |
| Root (builtin) type | | **URIorCURIE** |
| Representation | | str |
